# NTFS default use internal fuse-lite.

Summary:        NTFS filesystem userspace driver on Linux
Name:           ntfs-3g
Version:        2022.10.3
Release:        4%{?dist}
License:        GPLv2+
URL:            https://www.tuxera.com/company/open-source/
Source0:        http://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz
Patch3000:      ntfs-3g_ntfsprogs-2011.10.9-RC-ntfsck-unsupported-return-0.patch
# ntfs-3g BR
BuildRequires:  make gnutls-devel libattr-devel
# ntfsprogs BR
BuildRequires:  libconfig-devel libgcrypt-devel libtool libuuid-devel
Requires:       %{name}-libs = %{version}-%{release}
Provides:       ntfsprogs-fuse = %{version}-%{release}
Provides:       fuse-ntfs-3g = %{version}-%{release}

Patch0001:	CVE-2023-52890.patch

%description
The NTFS-3G driver is an open source, full-featured, portable, freely 
available read/write NTFS driver for Linux, FreeBSD, macOS, NetBSD, 
OpenIndiana, QNX and Haiku. It provides safe and fast handling of 
the Windows XP, Windows Server 2003, Windows 2000, Windows Vista, 
Windows Server 2008, Windows 7, Windows 8, Windows Server 2012,
Windows Server 2016, Windows 10 and Windows Server 2019 NTFS file
systems.

%package libs
Summary:        Runtime libraries for ntfs-3g

%description libs
Libraries provide api for applications to use ntfs-3g functionality.

%package devel
Summary:        Devel files like headers and libraries for ntfs-3g
Requires:       %{name}-libs = %{version}-%{release}
Provides:       ntfsprogs-devel = %{version}-%{release}

%description devel
Headers files and share libs for developing applications that use ntfs-3g
provide ability.

%package -n ntfsprogs
Summary:        NTFS filesystem libraries and tools
Requires:       %{name}-libs = %{version}-%{release}

%description -n ntfsprogs
The ntfsprogs package consists of a library and utilities such as
mkntfs, ntfscat, ntfsls, ntfsresize, and ntfsundelet , for detail 
list of utilities see man 8 ntfsprogs or upstream readme.

%prep
%autosetup -n %{name}_ntfsprogs-%{version} -p1


%build
CFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64"
%configure \
	--disable-static \
	--disable-ldconfig \
	--exec-prefix=/ \
	--enable-posix-acls \
	--enable-xattr-mappings \
	--enable-crypto \
	--enable-extras \
	--enable-quarantined
%make_build LIBTOOL=%{_bindir}/libtool


%install
%make_install LIBTOOL=%{_bindir}/libtool

find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_libdir}/*.a

rm -rf %{buildroot}/%{_sbindir}/mount.ntfs-3g
cp -a %{buildroot}/%{_bindir}/ntfs-3g %{buildroot}/%{_sbindir}/mount.ntfs-3g

pushd %{buildroot}/%{_bindir}
ln -s ntfs-3g ntfsmount
popd
pushd %{buildroot}/%{_sbindir}
ln -s mount.ntfs-3g mount.ntfs-fuse
ln -s mount.ntfs-3g mount.ntfs
ln -s ../bin/ntfsck fsck.ntfs
popd

mv %{buildroot}/sbin/* %{buildroot}/%{_sbindir}
rmdir %{buildroot}/sbin

rm -rf %{buildroot}%{_defaultdocdir}/%{name}/README

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog CREDITS NEWS README
%{_sbindir}/mount.ntfs
%{_sbindir}/mount.ntfs-3g
%{_sbindir}/mount.ntfs-fuse
%{_sbindir}/mount.lowntfs-3g
%{_bindir}/ntfs-3g
%{_bindir}/ntfsmount
%{_bindir}/ntfs-3g.probe
%{_bindir}/lowntfs-3g
%{_mandir}/man8/mount.lowntfs-3g.*
%{_mandir}/man8/mount.ntfs-3g.*
%{_mandir}/man8/ntfs-3g*

%files libs
%license COPYING
%{_libdir}/libntfs-3g.so.*

%files devel
%{_includedir}/ntfs-3g/
%{_libdir}/libntfs-3g.so
%{_libdir}/pkgconfig/libntfs-3g.pc

%files -n ntfsprogs
%license COPYING
%doc AUTHORS CREDITS ChangeLog NEWS README
%{_bindir}/ntfscat
%{_bindir}/ntfscluster
%{_bindir}/ntfscmp
%{_bindir}/ntfsfix
%{_bindir}/ntfsinfo
%{_bindir}/ntfsls
%{_bindir}/ntfssecaudit
%{_bindir}/ntfsusermap
%{_bindir}/ntfsck
%{_bindir}/ntfsdecrypt
%{_bindir}/ntfsdump_logfile
%{_bindir}/ntfsfallocate
%{_bindir}/ntfsmftalloc
%{_bindir}/ntfsmove
%{_bindir}/ntfsrecover
%{_bindir}/ntfstruncate
%{_bindir}/ntfswipe
%{_sbindir}/fsck.ntfs
%{_sbindir}/mkfs.ntfs
%{_sbindir}/mkntfs
%{_sbindir}/ntfsclone
%{_sbindir}/ntfscp
%{_sbindir}/ntfslabel
%{_sbindir}/ntfsresize
%{_sbindir}/ntfsundelete
%{_mandir}/man8/mkntfs.8*
%{_mandir}/man8/mkfs.ntfs.8*
%{_mandir}/man8/ntfs[^m][^o]*.8*
%exclude %{_mandir}/man8/ntfs-3g*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.10.3-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Tue Sep 24 2024 kianli <kianli@tencent.com> - 2022.10.3-3
- [Type] security
- [Desc] fix CVE-2023-52890

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.10.3-2
- Rebuilt for loongarch release

* Tue Sep 19 2023 jackeyji <jackeyji@tencent.com> - 2022.10.3-1
- upgrade to 2022.10.3 for CVE-2022-40284

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.5.17-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.5.17-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.5.17-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Jul 22 2022 Maxon Xie <maxonxie@tencent.com> - 2022.5.17-1
- Initial build
